package Acme::KMX::Test;

our $VERSION = '0.013';

sub demo0 { warn "0" };

1;

__END__

=head1 NAME

Acme::KMX::Test - Testing package

=head1 SYNOPSIS

 No synopsis.

=head1 DESCRIPTION

 No description.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=head1 COPYRIGHT

Copyright (c) 2014 KMX
